﻿using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Windows;

namespace JPing
{
    /// <summary>
    /// Setting window and about window.
    /// </summary>
    public partial class SettingWindow : Window
    {
        #region Constants

        /// <summary>
        /// MIT license.
        /// </summary>
        private const string LICENSE = "MIT LICENSE\nCopyright 2020 J.C\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files(the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.";

        /// <summary>
        /// Supported ping interval.
        /// </summary>
        private readonly List<float> INTERVAL_TABLE = new List<float> { 0.1F, 0.2F, 0.5F, 1.0F, 2.0F, 3.0F, 5.0F, 7.5F, 10.0F };

        /// <summary>
        /// Supported ping average.
        /// </summary>
        private readonly List<int> AVERAGE_TABLE = new List<int> { 3, 5, 10, 15, 20, 30 };

        #endregion


        #region Initialize

        /// <summary>
        /// Initialize setting & about window.
        /// </summary>
        public SettingWindow(Setting setting, int tab = 0)
        {
            InitializeComponent();
            InitializeComboBox();
            DataContext = setting;
            tabs.SelectedIndex = tab;
            version.Content = System.Reflection.Assembly.GetEntryAssembly().GetName().Version.ToString();
        }

        /// <summary>
        /// Initialize the content of combo-boxes.
        /// </summary>
        private void InitializeComboBox()
        {
            interval.ItemsSource = INTERVAL_TABLE;
            average.ItemsSource = AVERAGE_TABLE;
        }

        #endregion


        #region About Tab

        /// <summary>
        /// Browse hyperlink.
        /// </summary>
        private void Hyperlink_RequestNavigate(object sender, System.Windows.Navigation.RequestNavigateEventArgs e)
        {
            Process.Start(e.Uri.ToString());
        }

        /// <summary>
        /// Display MIT license.
        /// </summary>
        private void License_RequestNavigate(object sender, System.Windows.Navigation.RequestNavigateEventArgs e)
        {
            string dir = Path.GetRandomFileName();
            if (!Directory.Exists(dir))
                Directory.CreateDirectory(dir);
            string f = dir + @"\License.txt";
            File.WriteAllText(f, LICENSE);
            Process.Start(f);
            System.Threading.Thread.Sleep(1000);
            Directory.Delete(dir, true);
        }

        #endregion
    }
}
